==> opennms-util-1.7.91-sources.jar: org/opennms/core/utils/ReplaceAllOperation.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2010 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Modifications:
//
// 2008 Jun 16: Move RRD command-specific methods to JRobinRrdStrategy. - jeffg@opennms.org
// 2007 Jun 23: Use Java 5 generics. - dj@opennms.org
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.core.utils;

public class ReplaceAllOperation extends StringReplaceOperation {

    public ReplaceAllOperation(String spec) {
        super(spec);
    }
    
    @Override
    public String replace(String input) {
        return input.replaceAll(m_pattern, m_replacement);
    }

}

==> opennms-util-1.8.3-sources.jar: org/opennms/core/utils/ReplaceAllOperation.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2010 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Modifications:
//
// 2008 Jun 16: Move RRD command-specific methods to JRobinRrdStrategy. - jeffg@opennms.org
// 2007 Jun 23: Use Java 5 generics. - dj@opennms.org
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.core.utils;

/**
 * <p>ReplaceAllOperation class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
public class ReplaceAllOperation extends StringReplaceOperation {

    /**
     * <p>Constructor for ReplaceAllOperation.</p>
     *
     * @param spec a {@link java.lang.String} object.
     */
    public ReplaceAllOperation(String spec) {
        super(spec);
    }
    
    /** {@inheritDoc} */
    @Override
    public String replace(String input) {
        return input.replaceAll(m_pattern, m_replacement);
    }

}
